@@ -1,16 +1,17 @@
 package Math::GSL;
-use base qw(Exporter);
-use base qw(DynaLoader);
+use base 'Exporter';
+use base 'DynaLoader';
 use strict;
-use warnings;
-use Math::GSL::Machine qw/:all/;
-use Math::GSL::Const qw/:all/;
-use Math::GSL::Errno qw/:all/;
-use Math::GSL::Vector qw/:file/;
-use Math::GSL::Test qw/:all/;
-use Carp qw/croak/;
 use Config;
+use warnings;
 use Test::More;
+
+use Carp               qw/croak/;
+use Math::GSL::Test    qw/:all/;
+use Math::GSL::Const   qw/:all/;
+use Math::GSL::Errno   qw/:all/;
+use Math::GSL::Vector  qw/:file/;
+use Math::GSL::Machine qw/:all/;
 our @EXPORT = qw();
 our @EXPORT_OK = qw( 
                      gsl_fopen gsl_fclose 
@@ -23,15 +24,15 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK, );
 
 our ($GSL_PREC_DOUBLE, $GSL_PREC_SINGLE, $GSL_PREC_APPROX ) = 0 .. 2;
 our $GSL_MODE_DEFAULT = $GSL_PREC_DOUBLE;
-our $VERSION = '0.15_05';
+our $VERSION = '0.17_01';
 
 =head1 NAME
 
-Math::GSL - Perl interface to the  GNU Scientific Library (GSL) 
+Math::GSL - Perl interface to the GNU Scientific Library (GSL)
 
 =head1 VERSION
 
-Version 0.15_05
+Version 0.17_01
 
 =head1 SYNOPSIS
 
